/*
  *  Copyright © 2014 Copyright Clearance Center, Inc.
  *
  * Copyright Clearance Center licenses this file to You under the Apache License,
  * Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software distributed under
 *   the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 *   either express or implied. See the License for the specific language governing permissions and
 *   limitations under the License.
*/
package com.copyright.developers.blog.validators;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.validation.Errors;
import org.springframework.validation.SmartValidator;
import org.springframework.validation.Validator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Allows to configure multiple validators automatically while using annotation driven Spring MVC
 * configuration.
 */
@Component
public final class CompositeValidator implements SmartValidator {

    private Map<Class, Validator> validators = new HashMap<Class, Validator>();

    @Override
    public boolean supports(Class<?> clazz) {

        for(Validator validator : validators.values()) {
            if(validator.supports(clazz)) {
                return true;
            }
        }

        return false;
    }

    @Override
    public void validate(Object target, Errors errors) {

        for(Validator validator : validators.values()) {
            if(validator.supports(target.getClass())) {
                validator.validate(target, errors);
            }
        }
    }

    @Override
    public void validate(Object target, Errors errors, Object... validationHints) {

        for(Object validationHint : validationHints) {
            Class clazz = (Class) validationHint;
            validators.get(clazz).validate(target, errors);
        }
    }

    @Autowired
    public void setValidators(List<Validator> validators) {

        for(Validator validator : validators) {
            this.validators.put(validator.getClass(), validator);
        }
    }
}
